@@ -31,7 +31,8 @@ sub new {
     namespace_errors        => 0,
     %options }, $class;
   $$self{xpath}->registerFunction('match-font', \&LaTeXML::Common::Font::match_font);
-  $self->registerNamespace('xml', "http://www.w3.org/XML/1998/namespace");
+  $self->registerNamespace('xml', $LaTeXML::Common::XML::XML_NS);
+  $self->registerDocumentNamespace('xml', $LaTeXML::Common::XML::XML_NS);
   return $self; }
 
 sub setDocType {
@@ -98,6 +99,7 @@ sub compileSchema {
     foreach my $classname (sort keys %$defs) {
       print $classname. ':=(' . join(',', sort keys %{ $$self{schemaclass}{$classname} }) . ')' . "\n"; } }
   foreach my $tag (sort keys %{ $$self{tagprop} }) {
+    next if $tag =~ /^!/;    # Ignore top-level negated (only make sense in content model)
     print $tag
       . '{' . join(',', sort keys %{ $$self{tagprop}{$tag}{attributes} }) . '}'
       . '(' . join(',', sort keys %{ $$self{tagprop}{$tag}{model} }) . ')' . "\n"; }
@@ -262,15 +264,47 @@ sub getNodeQName {
     return '#ProcessingInstruction'; }
   elsif ($type == XML_DTD_NODE) {
     return '#DTD'; }
+  elsif ($type == XML_NAMESPACE_DECL) {
+    my $ns = $node->declaredURI;
+    my $prefix = $ns && $self->getNamespacePrefix($ns, 0, 1);
+    return ($prefix ? 'xmlns:' . $prefix : 'xmlns'); }
   # Need others?
   elsif (($type != XML_ELEMENT_NODE) && ($type != XML_ATTRIBUTE_NODE)) {
     Fatal('misdefined', '<caller>', undef,
       "Should not ask for Qualified Name for node of type $type: " . Stringify($node));
     return; }
-  elsif (my $ns = $node->namespaceURI) {
-    return $self->getNamespacePrefix($ns) . ":" . $node->localname; }
   else {
-    return $node->localname; } }
+    my $ns = $node->namespaceURI;
+    my $prefix = $ns && $self->getNamespacePrefix($ns, 0, 1);
+    return ($prefix ? $prefix . ":" . $node->localname : $node->localname); } }
+
+# Same thing, but using the Document namespace prefixes
+sub getNodeDocumentQName {
+  my ($self, $node) = @_;
+  my $type = $node->nodeType;
+  if ($type == XML_TEXT_NODE) {
+    return '#PCDATA'; }
+  elsif ($type == XML_DOCUMENT_NODE) {
+    return '#Document'; }
+  elsif ($type == XML_COMMENT_NODE) {
+    return '#Comment'; }
+  elsif ($type == XML_PI_NODE) {
+    return '#ProcessingInstruction'; }
+  elsif ($type == XML_DTD_NODE) {
+    return '#DTD'; }
+  elsif ($type == XML_NAMESPACE_DECL) {
+    my $ns = $node->declaredURI;
+    my $prefix = $ns && $self->getDocumentNamespacePrefix($ns, 0, 1);
+    return ($prefix ? 'xmlns:' . $prefix : 'xmlns'); }
+  # Need others?
+  elsif (($type != XML_ELEMENT_NODE) && ($type != XML_ATTRIBUTE_NODE)) {
+    Fatal('misdefined', '<caller>', undef,
+      "Should not ask for Qualified Name for node of type $type: " . Stringify($node));
+    return; }
+  else {
+    my $ns = $node->namespaceURI;
+    my $prefix = $ns && $self->getDocumentNamespacePrefix($ns, 0, 1);
+    return ($prefix ? $prefix . ":" . $node->localname : $node->localname); } }
 
 # Given a Document QName, convert to "code" form
 # Used to convert a possibly prefixed name from the DTD
@@ -297,12 +331,12 @@ sub getXPath {
 
 sub getTags {
   my ($self) = @_;
-  return keys %{ $$self{tagprop} }; }
+  return (sort keys %{ $$self{tagprop} }); }
 
 sub getTagContents {
   my ($self, $tag) = @_;
   my $h = $$self{tagprop}{$tag}{model};
-  return $h ? keys %$h : (); }
+  return ($h ? sort keys %$h : ()); }
 
 sub addTagContent {
   my ($self, $tag, @elements) = @_;
@@ -313,7 +347,7 @@ sub addTagContent {
 sub getTagAttributes {
   my ($self, $tag) = @_;
   my $h = $$self{tagprop}{$tag}{attributes};
-  return $h ? keys %$h : (); }
+  return $h ? sort keys %$h : (); }
 
 sub addTagAttribute {
   my ($self, $tag, @attributes) = @_;
@@ -351,8 +385,25 @@ sub canContain {
   return 1 if $$self{permissive} && ($tag eq '#Document') && ($childtag ne '#PCDATA'); # No DTD? Punt!
          # Else query tag properties.
   my $model = $$self{tagprop}{$tag}{model};
-  return $$model{ANY} || $$model{$childtag}; }
+  if (!$model && ($tag =~ /^(\w*):/)) {
+    my $xtag = $1 . ':*';
+    $model = $$self{tagprop}{$xtag}{model}; }
+  my ($chns, $chname) = ($childtag =~ /^([^:]*):(.*)$/ ? ($1, $2) : (undef, $childtag));
+  if ($chns) {
+    return ($$model{$childtag} ? 1
+      : ($$model{"!$childtag"} ? 0
+        : ($$model{"$chns:*"} ? 1
+          : ($$model{"!$chns:*"} ? 0
+            : ($$model{ANY} ? 1
+              : 0))))); }
+  else {
+    return ($$model{$childtag} ? 1
+      : ($$model{"!$childtag"} ? 0
+        : ($$model{ANY} ? 1
+          : 0))); } }
 
+# NOTE: Currently the Document class already allows ANY namespaced attributes!
+# (which is very unmodular, although it does have to arrange for namespace declarations)
 sub canHaveAttribute {
   my ($self, $tag, $attrib) = @_;
   $self->loadSchema unless $$self{schema_loaded};
@@ -361,8 +412,14 @@ sub canHaveAttribute {
   return 0 if $tag eq '#Document';
   return 0 if $tag eq '#ProcessingInstruction';
   return 0 if $tag eq '#DTD';
+  return 1 if $tag =~ /(.*?:)?_Capture_$/;
   return 1 if $$self{permissive};
-  return $$self{tagprop}{$tag}{attributes}{$attrib}; }
+  my $attr = $$self{tagprop}{$tag}{attributes};
+
+  if (!$attr && ($tag =~ /^(\w*):/)) {
+    my $xtag = $1 . ':*';
+    $attr = $$self{tagprop}{$xtag}{attributes}; }
+  return $$attr{ANY} || $$attr{$attrib}; }
 
 sub isInSchemaClass {
   my ($self, $classname, $tag) = @_;
@@ -388,7 +445,7 @@ sub describeModel {
 
 __END__
 
-=pod 
+=pod
 
 =head1 NAME
 
@@ -447,7 +504,7 @@ that are relevant to L<LaTeXML>.
 The `code' mapping is the one used in code implementing packages, and in
 particular, constructors defined within those packages.  The prefix C<ltx>
 is used consistently to refer to L<LaTeXML>'s own namespace
-(C<http://dlmf.nist.gov/LaTeXML)>. 
+(C<http://dlmf.nist.gov/LaTeXML)>.
 
 The other mapping, the `document' mapping, is used in the created document;
 this may be different from the `code' mapping in order to accommodate
@@ -480,7 +537,7 @@ Return the namespace url for the given C<$prefix>.
 
 =item C<< $boole = $model->canContain($tag,$childtag); >>
 
-Returns whether an element with qualified name C<$tag> can contain an element 
+Returns whether an element with qualified name C<$tag> can contain an element
 with qualified name C<$childtag>.
 The tag names #PCDATA, #Document, #Comment and #ProcessingInstruction
 are specially recognized.
