@@ -30,6 +30,7 @@ sub Number {
 
 sub new {
   my ($class, $number) = @_;
+  $number = ToString($number) if ref $number;
   return bless [$number || "0"], $class; }
 
 sub valueOf {
@@ -42,23 +43,30 @@ sub toString {
 
 my @SCALES = (1, 10, 100, 1000, 10000, 100000);
 
-sub ptValue {
-  my ($self, $prec) = @_;
+# smallest number that makes a difference added to 1 in Perl's float format.
+my $EPSILON = 1.0;
+while (1.0 + $EPSILON / 2 != 1) {
+  $EPSILON /= 2.0; }
+
+# Round $number to $prec decimals (0...6)
+# attempting to do so portably.
+sub roundto {
+  my ($number, $prec) = @_;
   $prec = 2 unless defined $prec;
   $prec = 0 if $prec < 0;
   $prec = 5 if $prec > 5;
   my $scale = $SCALES[$prec];
-  my $h     = $$self[0] * $scale / 65536;
-  return int($h < 0 ? $h - 0.5 : $h + 0.5) / $scale; }
+  # scale to integer, w/some slop in case arbitrarily close to an integer...
+  my $n = $number * $scale * (1 + 100 * $EPSILON);
+  return int($n < -$EPSILON ? $n - 0.5 : ($n > $EPSILON ? $n + 0.5 : 0.0)) / $scale; }
+
+sub ptValue {
+  my ($self, $prec) = @_;
+  return roundto($$self[0] / 65536, $prec); }
 
 sub pxValue {
   my ($self, $prec) = @_;
-  $prec = 2 unless defined $prec;
-  $prec = 0 if $prec < 0;
-  $prec = 5 if $prec > 5;
-  my $scale = $SCALES[$prec];
-  my $h = $$self[0] * $scale / 65536 * ($STATE->lookupValue('DPI') || 100 / 72.27);
-  return int($h < 0 ? $h - 0.5 : $h + 0.5) / $scale; }
+  return roundto($$self[0] / 65536 * ($STATE->lookupValue('DPI') || 100 / 72.27), $prec); }
 
 sub unlist {
   my ($self) = @_;
@@ -101,6 +109,16 @@ sub multiply {
   my ($self, $other) = @_;
   return (ref $self)->new(int($self->valueOf * (ref $other ? $other->valueOf : $other))); }
 
+# Truncating division
+sub divide {
+  my ($self, $other) = @_;
+  return (ref $self)->new(int($self->valueOf / (ref $other ? $other->valueOf : $other))); }
+
+# Rounding division
+sub divideround {
+  my ($self, $other) = @_;
+  return (ref $self)->new(int(0.5 + $self->valueOf / (ref $other ? $other->valueOf : $other))); }
+
 sub stringify {
   my ($self) = @_;
   return "Number[" . $$self[0] . "]"; }
@@ -185,6 +203,14 @@ Return an object representing the difference between C<$object> and C<$other>
 
 Return an object representing the product of C<$object> and C<$n> (a regular number).
 
+=item C<< $n = $object->divide($n); >>
+
+Return an object representing the (truncating) division of C<$object> by C<$n> (a regular number).
+
+=item C<< $n = $object->divideround($n); >>
+
+Return an object representing the (rounding) division of C<$object> by C<$n> (a regular number).
+
 =back
 
 =head1 AUTHOR
